@@ -95,6 +95,9 @@ FAILEDOPERATION_LOGINTIMEOUT = 'FailedOperation.LoginTimeout'
 # 用户手机没有通过验证。
 FAILEDOPERATION_MOBILENOTVERIFIED = 'FailedOperation.MobileNotVerified'
 
+# 请先添加默认线路的解析记录
+FAILEDOPERATION_MUSTADDDEFAULTLINEFIRST = 'FailedOperation.MustAddDefaultLineFirst'
+
 # 权限错误，您无法查看该任务的详情。
 FAILEDOPERATION_NOTBATCHTASKOWNER = 'FailedOperation.NotBatchTaskOwner'
 
@@ -149,6 +152,9 @@ INVALIDPARAMETER_ACTIONSUCCESS = 'InvalidParameter.ActionSuccess'
 # 用户未实名。
 INVALIDPARAMETER_ACTIVITY = 'InvalidParameter.Activity'
 
+# 该域名已在您的域名列表中，请删除后再添加到别名列表
+INVALIDPARAMETER_ALIASISMYDOMAIN = 'InvalidParameter.AliasIsMyDomain'
+
 # 创建批量域名任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHDOMAINCREATEACTIONERROR = 'InvalidParameter.BatchDomainCreateActionError'
 
